[cleanup] [minor] replaced for territory to applicable territory
diff --git a/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.js b/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.js
index f1a6027..a7a88d4 100644
--- a/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.js
+++ b/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.js
@@ -4,7 +4,7 @@
 //--------- ONLOAD -------------
 cur_frm.cscript.onload = function(doc, cdt, cdn) {
 	if(doc.doctype === "Sales Taxes and Charges Master")
-		erpnext.add_for_territory();
+		erpnext.add_applicable_territory();
 }
 
 cur_frm.cscript.refresh = function(doc, cdt, cdn) {
diff --git a/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.txt b/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.txt
index 20e4076..cddf10e 100644
--- a/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.txt
+++ b/accounts/doctype/sales_taxes_and_charges_master/sales_taxes_and_charges_master.txt
@@ -2,7 +2,7 @@
  {
   "creation": "2013-01-10 16:34:09", 
   "docstatus": 0, 
-  "modified": "2013-07-22 15:22:14", 
+  "modified": "2013-10-31 19:25:09", 
   "modified_by": "Administrator", 
   "owner": "Administrator"
  }, 
@@ -94,7 +94,7 @@
   "fieldname": "valid_for_territories", 
   "fieldtype": "Table", 
   "label": "Valid for Territories", 
-  "options": "For Territory", 
+  "options": "Applicable Territory", 
   "reqd": 1
  }, 
  {
diff --git a/accounts/doctype/sales_taxes_and_charges_master/test_sales_taxes_and_charges_master.py b/accounts/doctype/sales_taxes_and_charges_master/test_sales_taxes_and_charges_master.py
index 74b0b4e..7a013fb 100644
--- a/accounts/doctype/sales_taxes_and_charges_master/test_sales_taxes_and_charges_master.py
+++ b/accounts/doctype/sales_taxes_and_charges_master/test_sales_taxes_and_charges_master.py
@@ -25,7 +25,7 @@
 			"rate": 6.36,
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "All Territories"
 		}
@@ -113,7 +113,7 @@
 			"row_id": 7
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory India"
 		}
@@ -141,7 +141,7 @@
 			"rate": 4,
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "All Territories"
 		}
diff --git a/accounts/doctype/shipping_rule/shipping_rule.js b/accounts/doctype/shipping_rule/shipping_rule.js
index 2aeb8dd..2a0c433 100644
--- a/accounts/doctype/shipping_rule/shipping_rule.js
+++ b/accounts/doctype/shipping_rule/shipping_rule.js
@@ -3,6 +3,6 @@
 
 $.extend(cur_frm.cscript, {
 	onload: function() {
-		erpnext.add_for_territory();
+		erpnext.add_applicable_territory();
 	}
 });
\ No newline at end of file
diff --git a/accounts/doctype/shipping_rule/shipping_rule.txt b/accounts/doctype/shipping_rule/shipping_rule.txt
index 43589b4..27aaa70 100644
--- a/accounts/doctype/shipping_rule/shipping_rule.txt
+++ b/accounts/doctype/shipping_rule/shipping_rule.txt
@@ -2,7 +2,7 @@
  {
   "creation": "2013-06-25 11:48:03", 
   "docstatus": 0, 
-  "modified": "2013-07-05 14:55:00", 
+  "modified": "2013-10-31 19:24:50", 
   "modified_by": "Administrator", 
   "owner": "Administrator"
  }, 
@@ -87,7 +87,7 @@
   "fieldname": "valid_for_territories", 
   "fieldtype": "Table", 
   "label": "Valid For Territories", 
-  "options": "For Territory", 
+  "options": "Applicable Territory", 
   "reqd": 1
  }, 
  {
diff --git a/accounts/doctype/shipping_rule/test_shipping_rule.py b/accounts/doctype/shipping_rule/test_shipping_rule.py
index f85909e..a9aa4c7 100644
--- a/accounts/doctype/shipping_rule/test_shipping_rule.py
+++ b/accounts/doctype/shipping_rule/test_shipping_rule.py
@@ -62,7 +62,7 @@
 			"shipping_amount": 0.0
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory"
 		}
diff --git a/patches/october_2013/p07_rename_for_territory.py b/patches/october_2013/p07_rename_for_territory.py
new file mode 100644
index 0000000..2317002
--- /dev/null
+++ b/patches/october_2013/p07_rename_for_territory.py
@@ -0,0 +1,21 @@
+# Copyright (c) 2013, Web Notes Technologies Pvt. Ltd.
+# License: GNU General Public License v3. See license.txt
+
+from __future__ import unicode_literals
+import webnotes, os
+
+def execute():
+	webnotes.reload_doc("core", "doctype", "doctype")
+
+	tables = webnotes.conn.sql_list("show tables")
+	
+	if "tabApplicable Territory" not in tables:
+		webnotes.rename_doc("DocType", "For Territory", "Applicable Territory", force=True)
+	
+	webnotes.reload_doc("setup", "doctype", "applicable_territory")
+	
+	if os.path.exists("app/setup/doctype/for_territory"):
+		os.system("rm -rf app/setup/doctype/for_territory")
+	
+	if webnotes.conn.exists("DocType", "For Territory"):
+			webnotes.delete_doc("DocType", "For Territory")
\ No newline at end of file
diff --git a/patches/patch_list.py b/patches/patch_list.py
index 37220ab..67affb6 100644
--- a/patches/patch_list.py
+++ b/patches/patch_list.py
@@ -163,7 +163,6 @@
 	"execute:webnotes.delete_doc('Report', 'Sales Orders Pending To Be Delivered')",
 	"patches.june_2013.p05_remove_unused_doctypes",
 	"patches.june_2013.p06_drop_unused_tables",
-	"patches.june_2013.p07_taxes_price_list_for_territory",
 	"patches.june_2013.p08_shopping_cart_settings",
 	"patches.june_2013.p09_update_global_defaults",
 	"patches.june_2013.p10_lead_address",
@@ -228,4 +227,6 @@
 	"patches.october_2013.p04_update_report_permission",
 	"patches.october_2013.p05_delete_gl_entries_for_cancelled_vouchers",
 	"patches.october_2013.p06_update_control_panel_and_global_defaults",
+	"patches.october_2013.p07_rename_for_territory",
+	"patches.june_2013.p07_taxes_price_list_for_territory",
 ]
\ No newline at end of file
diff --git a/public/js/utils.js b/public/js/utils.js
index 61e613b..2dccd35 100644
--- a/public/js/utils.js
+++ b/public/js/utils.js
@@ -28,10 +28,10 @@
 		}
 	},
 	
-	add_for_territory: function() {
+	add_applicable_territory: function() {
 		if(cur_frm.doc.__islocal && 
 			wn.model.get_doclist(cur_frm.doc.doctype, cur_frm.doc.name).length === 1) {
-				var territory = wn.model.add_child(cur_frm.doc, "For Territory", 
+				var territory = wn.model.add_child(cur_frm.doc, "Applicable Territory", 
 					"valid_for_territories");
 				territory.territory = wn.defaults.get_default("territory");
 		}
diff --git a/stock/doctype/for_territory/__init__.py b/setup/doctype/applicable_territory/__init__.py
similarity index 100%
rename from stock/doctype/for_territory/__init__.py
rename to setup/doctype/applicable_territory/__init__.py
diff --git a/stock/doctype/for_territory/for_territory.py b/setup/doctype/applicable_territory/applicable_territory.py
similarity index 80%
rename from stock/doctype/for_territory/for_territory.py
rename to setup/doctype/applicable_territory/applicable_territory.py
index 784339d..3256c80 100644
--- a/stock/doctype/for_territory/for_territory.py
+++ b/setup/doctype/applicable_territory/applicable_territory.py
@@ -1,5 +1,5 @@
 # Copyright (c) 2013, Web Notes Technologies Pvt. Ltd.
-# License: GNU General Public License v3. See license.txt
+# MIT License. See license.txt
 
 # For license information, please see license.txt
 
diff --git a/stock/doctype/for_territory/for_territory.txt b/setup/doctype/applicable_territory/applicable_territory.txt
similarity index 83%
rename from stock/doctype/for_territory/for_territory.txt
rename to setup/doctype/applicable_territory/applicable_territory.txt
index be454ec..31064de 100644
--- a/stock/doctype/for_territory/for_territory.txt
+++ b/setup/doctype/applicable_territory/applicable_territory.txt
@@ -2,7 +2,7 @@
  {
   "creation": "2013-06-20 12:48:38", 
   "docstatus": 0, 
-  "modified": "2013-07-10 14:54:09", 
+  "modified": "2013-10-31 18:56:54", 
   "modified_by": "Administrator", 
   "owner": "Administrator"
  }, 
@@ -20,7 +20,7 @@
   "label": "Territory", 
   "name": "__common__", 
   "options": "Territory", 
-  "parent": "For Territory", 
+  "parent": "Applicable Territory", 
   "parentfield": "fields", 
   "parenttype": "DocType", 
   "permlevel": 0, 
@@ -28,7 +28,7 @@
  }, 
  {
   "doctype": "DocType", 
-  "name": "For Territory"
+  "name": "Applicable Territory"
  }, 
  {
   "doctype": "DocField"
diff --git a/setup/doctype/setup_control/setup_control.py b/setup/doctype/setup_control/setup_control.py
index 818e310..9599e58 100644
--- a/setup/doctype/setup_control/setup_control.py
+++ b/setup/doctype/setup_control/setup_control.py
@@ -85,7 +85,7 @@
 					"currency": args["currency"]
 				},
 				{
-					"doctype": "For Territory",
+					"doctype": "Applicable Territory",
 					"parentfield": "valid_for_territories",
 					"territory": "All Territories"
 				}
diff --git a/stock/doctype/item_price/item_price.txt b/stock/doctype/item_price/item_price.txt
index 779bbd4..fc411eb 100644
--- a/stock/doctype/item_price/item_price.txt
+++ b/stock/doctype/item_price/item_price.txt
@@ -2,7 +2,7 @@
  {
   "creation": "2013-05-02 16:29:48", 
   "docstatus": 0, 
-  "modified": "2013-10-21 15:11:20", 
+  "modified": "2013-10-31 12:59:02", 
   "modified_by": "Administrator", 
   "owner": "Administrator"
  }, 
@@ -14,7 +14,7 @@
   "icon": "icon-flag", 
   "in_create": 0, 
   "istable": 0, 
-  "module": "Setup", 
+  "module": "Stock", 
   "name": "__common__", 
   "read_only": 0
  }, 
diff --git a/stock/doctype/price_list/price_list.js b/stock/doctype/price_list/price_list.js
index 84c4c2f..be3aeaa 100644
--- a/stock/doctype/price_list/price_list.js
+++ b/stock/doctype/price_list/price_list.js
@@ -3,7 +3,7 @@
 
 $.extend(cur_frm.cscript, {
 	onload: function() {
-		erpnext.add_for_territory();
+		erpnext.add_applicable_territory();
 	},
 
 	refresh: function() {
diff --git a/stock/doctype/price_list/price_list.py b/stock/doctype/price_list/price_list.py
index d94b78e..993f4ea 100644
--- a/stock/doctype/price_list/price_list.py
+++ b/stock/doctype/price_list/price_list.py
@@ -18,7 +18,7 @@
 			# if no territory, set default territory
 			if webnotes.defaults.get_user_default("territory"):
 				self.doclist.append({
-					"doctype": "For Territory",
+					"doctype": "Applicable Territory",
 					"parentfield": "valid_for_territories",
 					"territory": webnotes.defaults.get_user_default("territory")
 				})
diff --git a/stock/doctype/price_list/price_list.txt b/stock/doctype/price_list/price_list.txt
index b93cfcc..d43076b 100644
--- a/stock/doctype/price_list/price_list.txt
+++ b/stock/doctype/price_list/price_list.txt
@@ -2,7 +2,7 @@
  {
   "creation": "2013-01-25 11:35:09", 
   "docstatus": 0, 
-  "modified": "2013-10-18 13:33:07", 
+  "modified": "2013-10-31 19:24:33", 
   "modified_by": "Administrator", 
   "owner": "Administrator"
  }, 
@@ -17,7 +17,7 @@
   "document_type": "Master", 
   "icon": "icon-tags", 
   "max_attachments": 1, 
-  "module": "Setup", 
+  "module": "Stock", 
   "name": "__common__"
  }, 
  {
@@ -81,7 +81,7 @@
   "fieldname": "valid_for_territories", 
   "fieldtype": "Table", 
   "label": "Valid for Territories", 
-  "options": "For Territory", 
+  "options": "Applicable Territory", 
   "reqd": 1
  }, 
  {
diff --git a/stock/doctype/price_list/test_price_list.py b/stock/doctype/price_list/test_price_list.py
index d5174ed..e3fa791 100644
--- a/stock/doctype/price_list/test_price_list.py
+++ b/stock/doctype/price_list/test_price_list.py
@@ -15,7 +15,7 @@
 			"buying_or_selling": "Selling"
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "All Territories"
 		},
@@ -28,7 +28,7 @@
 			"buying_or_selling": "Selling"
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory Rest of the World"
 		}
@@ -41,7 +41,7 @@
 			"buying_or_selling": "Selling"
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory India"
 		}
@@ -54,12 +54,12 @@
 			"buying_or_selling": "Selling"
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory Rest of the World"
 		},
 		{
-			"doctype": "For Territory",
+			"doctype": "Applicable Territory",
 			"parentfield": "valid_for_territories",
 			"territory": "_Test Territory United States"
 		}
diff --git a/utilities/demo/demo_docs/Price_List.csv b/utilities/demo/demo_docs/Price_List.csv
index fb41239..1e0dcec 100644
--- a/utilities/demo/demo_docs/Price_List.csv
+++ b/utilities/demo/demo_docs/Price_List.csv
@@ -11,7 +11,7 @@
 "For updating, you can update only selective columns.",,,,,,,,,,,
 You can only upload upto 5000 records in one go. (may be less in some cases),,,,,,,,,,,
 ,,,,,,,,,,,
-DocType:,Price List,,,,~,For Territory,valid_for_territories,~,Item Price,item_prices,
+DocType:,Price List,,,,~,Applicable Territory,valid_for_territories,~,Item Price,item_prices,
 Column Labels:,ID,Price List Name,Currency,Valid for Buying or Selling?,,ID,Territory,,ID,Item Code,Rate
 Column Name:,name,price_list_name,currency,buying_or_selling,~,name,territory,~,name,item_code,ref_rate
 Mandatory:,Yes,Yes,Yes,Yes,,Yes,Yes,,Yes,Yes,Yes
diff --git a/patches/june_2013/p07_taxes_price_list_for_territory.py b/patches/june_2013/p07_taxes_price_list_for_territory.py
index d523ea9..f6663bf 100644
--- a/patches/june_2013/p07_taxes_price_list_for_territory.py
+++ b/patches/june_2013/p07_taxes_price_list_for_territory.py
@@ -4,7 +4,7 @@
 import webnotes
 
 def execute():
-	webnotes.reload_doc("stock", "doctype", "for_territory")
+	webnotes.reload_doc("setup", "doctype", "applicable_territory")
 	webnotes.reload_doc("stock", "doctype", "price_list")
 	webnotes.reload_doc("accounts", "doctype", "sales_taxes_and_charges_master")
 	webnotes.reload_doc("accounts", "doctype", "shipping_rule")
@@ -14,12 +14,12 @@
 	
 	for parenttype in ["Sales Taxes and Charges Master", "Price List", "Shipping Rule"]:
 		for name in webnotes.conn.sql_list("""select name from `tab%s` main
 			where not exists (select parent from `tabFor Territory` territory
 				where territory.parenttype=%s and territory.parent=main.name)""" % \
 				(parenttype, "%s"), (parenttype,)):
 			
 			doc = webnotes.doc({
-				"doctype": "For Territory",
+				"doctype": "Applicable Territory",
 				"__islocal": 1,
 				"parenttype": parenttype,
 				"parentfield": "valid_for_territories",
@@ -14,12 +14,12 @@
 	for parenttype in ["Sales Taxes and Charges Master", "Price List", "Shipping Rule"]:
 		for name in webnotes.conn.sql_list("""select name from `tab%s` main
-			where not exists (select parent from `tabFor Territory` territory
+			where not exists (select parent from `tabApplicable Territory` territory
 				where territory.parenttype=%s and territory.parent=main.name)""" % \
 				(parenttype, "%s"), (parenttype,)):